@@ -1,4 +1,4 @@
-/* @(#)btorder.h	1.3 97/08/25 Copyright 1996 J. Schilling */
+/* @(#)btorder.h	1.7 98/07/20 Copyright 1996 J. Schilling */
 /*
  *	Definitions for Bitordering
  *
@@ -26,12 +26,18 @@
 
 #include <sys/types.h>			/* try to load isa_defs.h on Solaris */
 
-#if	defined(_BIT_FIELDS_LTOH)	/* Intel byteorder */
-#elif	defined(_BIT_FIELDS_HTOL)	/* Motorola byteorder */
+
+#if	defined(_BIT_FIELDS_LTOH) || defined(_BIT_FIELDS_HTOL)
+/*
+ * Bitorder is known.
+ */
 #else
+/*
+ * Bitorder not known.
+ */
 #	if defined(sun3) || defined(mc68000) || \
 	   defined(sun4) || defined(__sparc) || defined(sparc) || \
-	   defined(__hppa)
+	   defined(__hppa) || defined(_ARCH_PPC) || defined(_IBMR2)
 #		define _BIT_FIELDS_HTOL
 #	endif
 
@@ -43,6 +49,16 @@
 	   defined(__alpha) || defined(alpha)
 #		define _BIT_FIELDS_LTOH
 #	endif
+
+#	if defined(__ppc__) || defined(ppc) || defined(__ppc) || \
+	   defined(__PPC) || defined(powerpc)
+
+#		if	defined(__BIG_ENDIAN__)
+#			define _BIT_FIELDS_HTOL
+#		else
+#			define _BIT_FIELDS_LTOH
+#		endif
+#	endif
 #endif
 
 #endif	/* _BTORDER_H */
